@@ -26,8 +26,7 @@ from snakeoil.contexts import chdir
 from snakeoil.currying import post_curry, pretty_docs
 from snakeoil.fileutils import touch
 from snakeoil.osutils import ensure_dirs, listdir_files, normpath, pjoin
-from snakeoil.process.spawn import (is_sandbox_capable, is_userpriv_capable,
-                                    spawn, spawn_bash)
+from snakeoil.process.spawn import is_sandbox_capable, is_userpriv_capable, spawn, spawn_bash
 from snakeoil.sequences import iflatten_instance, iter_stable_unique
 
 from .. import const
@@ -36,16 +35,14 @@ from ..operations import format, observer
 from ..os_data import portage_gid, portage_uid, xargs
 from ..package.mutated import MutatedPkg
 from . import ebd_ipc, ebuild_built, errors
-from .processor import (ProcessorError, chuck_UnhandledCommand,
-                        expected_ebuild_env, inherit_handler,
-                        release_ebuild_processor, request_ebuild_processor)
+from .processor import (ProcessorError, chuck_UnhandledCommand, expected_ebuild_env,
+                        inherit_handler, release_ebuild_processor, request_ebuild_processor)
 
 
 class ebd:
 
     def __init__(self, pkg, initial_env=None, env_data_source=None,
-                 observer=None, clean=True, tmp_offset=None,
-                 allow_fetching=False):
+                 observer=None, clean=True, tmp_offset=None):
         """
         :param pkg:
             :class:`pkgcore.ebuild.ebuild_src.package`
@@ -56,7 +53,6 @@ class ebd:
             state of an ebuild processing, whether for unmerging, or
             walking phases during building
         """
-        self.allow_fetching = allow_fetching
         self.pkg = pkg
         self.eapi = pkg.eapi
 
@@ -215,7 +211,8 @@ class ebd:
         for x, y in (("T", "temp"),
                      ("WORKDIR", "work"),
                      ("D", "image"),
-                     ("HOME", "homedir")):
+                     ("HOME", "homedir"),
+                     ("PKGCORE_EMPTYDIR", "empty")):
             self.env[x] = normpath(pjoin(self.builddir, y))
         self.env["D"] += self.eapi.options.trailing_slash
         self.env["PORTAGE_LOGFILE"] = normpath(pjoin(self.env["T"], "build.log"))
@@ -317,6 +314,10 @@ class ebd:
                 return True
             if 'selinux' not in self.features and 'suidctl' not in self.features:
                 return True
+
+        shutil.rmtree(self.env["PKGCORE_EMPTYDIR"], ignore_errors=True)
+        os.mkdir(self.env["PKGCORE_EMPTYDIR"])
+
         userpriv = self.userpriv and userpriv
         sandbox = self.sandbox and sandbox
         self._set_per_phase_env(phase, self.env)
@@ -667,28 +668,20 @@ class buildable(ebd, setup_mixin, format.build):
             self.env["ECLASSDIR"] = eclass_cache.eclassdir
 
         if self.setup_is_for_src:
-            self._init_distfiles_env()
-
-    def _init_distfiles_env(self):
-        # TODO: PORTAGE_ACTUAL_DISTDIR usage by vcs eclasses needs to be killed off
-        distdir_write = self.domain.fetcher.get_storage_path()
-        if distdir_write is None:
-            raise format.GenericBuildError(
-                "no usable distdir was found "
-                f"for PORTAGE_ACTUAL_DISTDIR from fetcher {self.domain.fetcher}")
-        self.env["PORTAGE_ACTUAL_DISTDIR"] = distdir_write
-        self.env["DISTDIR"] = normpath(
-            pjoin(self.builddir, "distdir"))
-        for x in ("PORTAGE_ACTUAL_DISTDIR", "DISTDIR"):
-            self.env[x] = os.path.realpath(self.env[x]).rstrip(os.sep) + os.sep
+            # TODO: PORTAGE_ACTUAL_DISTDIR usage by VCS eclasses needs to be
+            # dropped, but it's currently required for repo reuse.
+            self.env['PORTAGE_ACTUAL_DISTDIR'] = domain.distdir
+            self.env['DISTDIR'] = normpath(pjoin(self.builddir, 'distdir'))
+            for k in ('PORTAGE_ACTUAL_DISTDIR', 'DISTDIR'):
+                self.env[k] = os.path.realpath(self.env[k]).rstrip(os.sep) + os.sep
 
     def _setup_distfiles(self):
-        if not self.verified_files and self.allow_fetching:
+        # fetch distfiles
+        if not self.verified_files:
             ops = self.domain.pkg_operations(self.pkg, observer=self.observer)
-            if not ops.fetch():
-                raise format.GenericBuildError("failed fetching required distfiles")
-            self.verified_files = ops._fetch_op.verified_files
+            ops.fetch()
 
+        # symlink them into builddir
         if self.verified_files:
             try:
                 if os.path.exists(self.env["DISTDIR"]):
@@ -897,10 +890,9 @@ class ebuild_operations:
         """Run all defined sanity checks."""
         failures = []
         for check in self._checks:
-            result = check(self, self.pkg, domain=domain)
-            if result is not None:
+            if result := check(self, self.pkg, domain=domain):
                 failures.append(result)
-        return self.pkg, failures
+        return failures
 
     @_register_check(_checks)
     def _check_required_use(self, pkg, **kwargs):
@@ -910,8 +902,7 @@ class ebuild_operations:
         against a known set of enabled USE flags and is in collapsed form.
         """
         if pkg.eapi.options.has_required_use:
-            failures = tuple(node for node in pkg.required_use if not node.match(pkg.use))
-            if failures:
+            if failures := tuple(node for node in pkg.required_use if not node.match(pkg.use)):
                 return errors.RequiredUseError(pkg, failures)
 
     @_register_check(_checks)
@@ -953,17 +944,16 @@ class ebuild_operations:
 
 class src_operations(ebuild_operations, format.build_operations):
 
-    def __init__(self, domain, pkg, eclass_cache, fetcher=None, observer=None):
+    def __init__(self, domain, pkg, eclass_cache, observer=None):
         format.build_operations.__init__(self, domain, pkg, observer=observer)
-        self._fetcher = fetcher
         self._eclass_cache = eclass_cache
 
     def _cmd_implementation_build(self, observer, verified_files,
-                                  clean=False, allow_fetching=False, force_test=False):
+                                  clean=False, force_test=False):
         return buildable(
             self.domain, self.pkg, verified_files,
             self._eclass_cache, observer=observer,
-            clean=clean, allow_fetching=allow_fetching, force_test=force_test)
+            clean=clean, force_test=force_test)
 
 
 class misc_operations(ebd):
@@ -981,9 +971,8 @@ class misc_operations(ebd):
 
 class built_operations(ebuild_operations, format.operations):
 
-    def __init__(self, domain, pkg, fetcher=None, observer=None, initial_env=None):
+    def __init__(self, domain, pkg, observer=None, initial_env=None):
         format.operations.__init__(self, domain, pkg, observer=observer)
-        self._fetcher = fetcher
         self._initial_env = initial_env
         self._localized_ebd = None
 
