@@ -13,9 +13,9 @@ from snakeoil.strings import pluralism
 from snakeoil.version import get_version
 
 from .. import __title__
+from ..log import logger
 from . import conditionals
 from .eapi import EAPI
-from ..log import logger
 
 
 class AttrDict(ImmutableDict):
@@ -210,7 +210,7 @@ class EclassBlock(ParseEclassDoc):
             '@VCSURL:': ('vcsurl', False, self._tag_inline_arg, None),
             '@BLURB:': ('blurb', True, self._tag_inline_arg, None),
             '@DEPRECATED:': ('deprecated', False, self._tag_deprecated, False),
-            '@INDIRECT_ECLASSES:': ('indirect_eclasses', False, self._tag_inline_list, ()),
+            '@PROVIDES:': ('raw_provides', False, self._tag_inline_list, ()),
             '@MAINTAINER:': ('maintainers', True, self._tag_multiline_args, None),
             '@AUTHOR:': ('authors', False, self._tag_multiline_args, None),
             '@BUGREPORTS:': ('bugreports', False, self._tag_multiline_str, None),
@@ -319,18 +319,35 @@ _eclass_blocks_re = re.compile(
 class EclassDoc(AttrDict):
     """Support parsing eclass docs for a given eclass path."""
 
-    def __init__(self, path, /, *, sourced=False):
+    def __init__(self, path, /, *, sourced=False, repo=None):
         self.mtime = os.path.getmtime(path)
 
         # parse eclass doc
         data = self.parse(path)
 
+        self._provides = None
+        if repo is not None:
+            self._provides = self._get_provides(data['raw_provides'], repo)
+
         # inject full lists of exported funcs and vars
         if sourced:
             data.update(self._source_eclass(path))
 
         super().__init__(data)
 
+    @staticmethod
+    def _get_provides(raw_provides, repo):
+        out = OrderedSet()
+        to_process = OrderedSet(raw_provides)
+        while to_process:
+            out.add(next_eclass := to_process.pop())
+            if (next_eclass_inst := repo.eclass_cache.get_eclass(next_eclass)) is None:
+                logger.warning(f"'@PROVIDES:' eclass {next_eclass} not found")
+                continue
+            next_eclass_doc = EclassDoc(next_eclass_inst.path)
+            to_process.update(set(next_eclass_doc.raw_provides).difference(out))
+        return out
+
     @staticmethod
     def _source_eclass(path):
         data = {}
@@ -409,6 +426,13 @@ class EclassDoc(AttrDict):
         """Eclass implements functionality to support a version control system."""
         return 'live' in self._dict.get('_properties', ())
 
+    @property
+    def provides(self):
+        """Recursively gathered list of other eclasses provided by this eclass."""
+        if self._provides is None:
+            raise ValueError('EclassDoc.provides can only be used if the class has been initialized with repo')
+        return self._provides
+
     @staticmethod
     def parse(path):
         """Parse eclass docs."""
@@ -509,6 +533,10 @@ class EclassDoc(AttrDict):
             rst.extend(_rst_header('-', 'Supported EAPIs'))
             rst.append(' '.join(self.supported_eapis))
             rst.append('')
+        if self.raw_provides:
+            rst.extend(_rst_header('-', 'Transitively Provided Eclasses'))
+            rst.append(' '.join(self.raw_provides))
+            rst.append('')
         if self.example:
             rst.extend(_rst_header('-', 'Example'))
             rst.append(self.example)
@@ -531,14 +559,28 @@ class EclassDoc(AttrDict):
         if external_vars := [x for x in self.variables if not x.internal]:
             rst.extend(_header_only('-', 'Variables'))
             for var in external_vars:
-                rst.extend(_rst_header('~', var.name))
+                vartype = ''
+                if var.required:
+                    vartype += ' (REQUIRED)'
+                if var.pre_inherit:
+                    vartype += ' (SET BEFORE INHERIT)'
+                if var.user_variable:
+                    vartype += ' (USER VARIABLE)'
+                if var.output_variable:
+                    vartype += ' (OUTPUT VARIABLE)'
+
+                rst.extend(_rst_header('~', var.name + vartype))
                 if var.description:
                     rst.append(var.description)
                 rst.append('')
         if external_func_vars := [x for x in self.function_variables if not x.internal]:
             rst.extend(_header_only('-', 'Function Variables'))
             for var in external_func_vars:
-                rst.extend(_rst_header('~', var.name))
+                vartype = ''
+                if var.required:
+                    vartype += ' (REQUIRED)'
+
+                rst.extend(_rst_header('~', var.name + vartype))
                 if var.description:
                     rst.append(var.description)
                 rst.append('')
