@@ -431,6 +431,13 @@ class ProfileNode(metaclass=caching.WeakInstMeta):
         c.freeze()
         return c
 
+    @load_property('make.defaults', read_func=None, fallback=None)
+    def make_defaults(self, data):
+        d = {}
+        if data is not None:
+            d.update(read_bash_dict(data[0]))
+        return ImmutableDict(d)
+
     @load_property('make.defaults', read_func=None, fallback=None)
     def default_env(self, data):
         rendered = _make_incrementals_dict()
@@ -702,7 +709,13 @@ class ProfileStack:
     def provides_repo(self):
         # delay importing to avoid circular imports
         from .repository import ProvidesRepo
-        return ProvidesRepo(pkgs=self._collapse_generic("pkg_provided"))
+        pkgs = self._collapse_generic('pkg_provided')
+        try:
+            arches = self._system_profile.repoconfig.known_arches
+        except AttributeError:
+            # TODO: repoconfig is None when using fake repos
+            arches = ()
+        return ProvidesRepo(pkgs, arches)
 
     @klass.jit_attr
     def masks(self):
