@@ -250,7 +250,7 @@ output_options.add_argument(
     docs="""
         Select an output formatter to use for text formatting of --pretend or
         --ask output, currently available formatters include the following:
-        basic, pkgcore, portage, portage-verbose, and paludis.
+        basic, pkgcore, portage, and portage-verbose.
 
         The basic formatter is the nearest to simple text output and is
         intended for scripting while the portage/portage-verbose formatter
@@ -592,7 +592,7 @@ def main(options, out, err):
         world_list=world_list,
         verbosity=options.verbosity,
         installed_repos=domain.all_installed_repos,
-        distdir=domain.fetcher.get_storage_path(),
+        distdir=domain.distdir,
         quiet_repo_display=options.quiet_repo_display)
 
     # This mode does not care about sets and packages so bypass all that.
@@ -821,9 +821,9 @@ def main(options, out, err):
                 start_time = time()
             # flush output so bash spawned errors are shown in the correct order of events
             out.flush()
-            sanity_failures = run_sanity_checks((x.pkg for x in changes), domain, threads=1)
+            sanity_failures = run_sanity_checks((x.pkg for x in changes), domain)
             if sanity_failures:
-                for pkg, errors in sanity_failures.items():
+                for errors in sanity_failures.values():
                     out.write('\n'.join(e.msg(verbosity=options.verbosity) for e in errors))
                     if options.verbosity > 0:
                         out.write()
