@@ -55,7 +55,7 @@ class DataSourceRestriction(values.base):
     __hash__ = object.__hash__
 
 
-dep_attrs = ['bdepend', 'depend', 'rdepend', 'pdepend']
+dep_attrs = ['bdepend', 'depend', 'rdepend', 'pdepend', 'idepend']
 metadata_attrs = dep_attrs
 dep_attrs += list(f'raw_{x}' for x in dep_attrs)
 dep_formatted_attrs = dep_attrs + ['restrict']
@@ -701,7 +701,7 @@ def parse_revdep(value):
         values.AnyMatch(values.FunctionRestriction(targetatom.intersects)))
     return packages.OrRestriction(*list(
         packages.PackageRestriction(dep, val_restrict)
-        for dep in ('bdepend', 'depend', 'rdepend', 'pdepend')))
+        for dep in dep_attrs))
 
 def _revdep_pkgs_match(pkgs, value):
     return any(value.match(pkg) for pkg in pkgs)
@@ -722,7 +722,7 @@ def revdep_pkgs_finalize(sequence, namespace):
         values.FunctionRestriction(partial(_revdep_pkgs_match, tuple(l))))
     r = values.FlatteningRestriction(atom.atom, any_restrict)
     return list(packages.PackageRestriction(dep, r)
-                for dep in ('bdepend', 'depend', 'rdepend', 'pdepend'))
+                for dep in dep_attrs)
 
 @bind_add_query(
     '-S', '--description', action='append',
@@ -972,9 +972,9 @@ def _validate_args(parser, namespace):
             elif attr == 'allmetadata':
                 i = process_attrs(metadata_attrs)
             elif attr == 'alldepends':
-                i = ['bdepend', 'depend', 'rdepend', 'pdepend']
+                i = dep_attrs
             elif attr == 'raw_alldepends':
-                i = ['raw_bdepend', 'raw_depend', 'raw_rdepend', 'raw_pdepend']
+                i = [f'raw_{x}' for x in dep_attrs]
             else:
                 i = [attr]
             for attr in i:
